@@ -6,7 +6,7 @@ use warnings;
 
 use DateTime;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our $_Current_Dt; # for testing only, to mock current time
 
@@ -18,7 +18,7 @@ my %short_id_month_names = (
     mei => 5,
     jun => 6,
     jul => 7,
-    agu => 8, agt => 8,
+    agu => 8, ags => 8, agt => 8,
     sep => 9, sept => 9,
     okt => 10,
     nop => 11, nov => 11,
@@ -134,7 +134,7 @@ DateTime::Format::Indonesian - Parse and format Indonesian dates
 
 =head1 VERSION
 
-This document describes version 0.02 of DateTime::Format::Indonesian (from Perl distribution DateTime-Format-Indonesian), released on 2015-01-03.
+This document describes version 0.03 of DateTime::Format::Indonesian (from Perl distribution DateTime-Format-Indonesian), released on 2015-08-10.
 
 =head1 SYNOPSIS
 
